==> ejc-settlementmanage-impl-3.0.0-20230510.092559-248-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookOtherDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-支出明细-其它
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_other")
public class SettlementBookOtherDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="deductions_name")
    private java.lang.String deductionsName; // 扣款名称
    @TableField(value="units")
    private java.lang.String unitsC; // 单位
    @TableField(value="number")
    private java.math.BigDecimal number; // 数量
    @TableField(value="extax_unitprice")
    private java.math.BigDecimal extaxUnitpriceC; // 除税单价
    @TableField(value="intax_unitprice")
    private java.math.BigDecimal intaxUnitpriceC; // 含税单价
    @TableField(value="extax_price")
    private java.math.BigDecimal extaxPriceC; // 除税金额
    @TableField(value="intax_price")
    private java.math.BigDecimal intaxPriceC; // 含税金额
    @TableField(value="remarks")
    private java.lang.String remarksC; // 单位
    @TableField(value="withholding_other")
    private java.lang.String withholdingOther; // 扣款类型
    @TableField(value="cum_extax_price")
    private java.math.BigDecimal cumExtaxPrice; // 累计除税金额
    @TableField(value="cum_intax_price")
    private java.math.BigDecimal cumIntaxPrice; // 累计含税金额
    @TableField(value="cur_extax_price")
    private java.math.BigDecimal curExtaxPrice; // 本期除税金额
    @TableField(value="cur_intax_price")
    private java.math.BigDecimal curIntaxPrice; // 本期含税金额
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 扣款名称
     */
    public java.lang.String getDeductionsName() {
        return deductionsName;
    }

    /**
     * 扣款名称
     */
    public void setDeductionsName(java.lang.String deductionsName) {
        this.deductionsName = deductionsName;
    }

    /**
     * 数量
     */
    public java.math.BigDecimal getNumber() {
        return number;
    }

    /**
     * 数量
     */
    public void setNumber(java.math.BigDecimal number) {
        this.number = number;
    }


    public BigDecimal getIntaxUnitpriceC() {
        return intaxUnitpriceC;
    }

    public void setIntaxUnitpriceC(BigDecimal intaxUnitpriceC) {
        this.intaxUnitpriceC = intaxUnitpriceC;
    }

    public BigDecimal getIntaxPriceC() {
        return intaxPriceC;
    }

    public void setIntaxPriceC(BigDecimal intaxPriceC) {
        this.intaxPriceC = intaxPriceC;
    }

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    public String getUnitsC() {
        return unitsC;
    }

    public void setUnitsC(String unitsC) {
        this.unitsC = unitsC;
    }

    public BigDecimal getExtaxUnitpriceC() {
        return extaxUnitpriceC;
    }

    public void setExtaxUnitpriceC(BigDecimal extaxUnitpriceC) {
        this.extaxUnitpriceC = extaxUnitpriceC;
    }

    public BigDecimal getExtaxPriceC() {
        return extaxPriceC;
    }

    public void setExtaxPriceC(BigDecimal extaxPriceC) {
        this.extaxPriceC = extaxPriceC;
    }

    public String getRemarksC() {
        return remarksC;
    }

    public void setRemarksC(String remarksC) {
        this.remarksC = remarksC;
    }

    public BigDecimal getCumExtaxPrice() {
        return cumExtaxPrice;
    }

    public void setCumExtaxPrice(BigDecimal cumExtaxPrice) {
        this.cumExtaxPrice = cumExtaxPrice;
    }

    public BigDecimal getCumIntaxPrice() {
        return cumIntaxPrice;
    }

    public void setCumIntaxPrice(BigDecimal cumIntaxPrice) {
        this.cumIntaxPrice = cumIntaxPrice;
    }

    public BigDecimal getCurExtaxPrice() {
        return curExtaxPrice;
    }

    public void setCurExtaxPrice(BigDecimal curExtaxPrice) {
        this.curExtaxPrice = curExtaxPrice;
    }

    public BigDecimal getCurIntaxPrice() {
        return curIntaxPrice;
    }

    public void setCurIntaxPrice(BigDecimal curIntaxPrice) {
        this.curIntaxPrice = curIntaxPrice;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20240628.063848-285-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookOtherDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-支出明细-其它
 *
 * @author generator
 *
 */
 @TableName("ejc_settlementmanage_settlement_book_other")
public class SettlementBookOtherDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="deductions_name")
    private java.lang.String deductionsName; // 扣款名称
    @TableField(value="units")
    private java.lang.String unitsC; // 单位
    @TableField(value="number")
    private java.math.BigDecimal number; // 数量
    @TableField(value="extax_unitprice")
    private java.math.BigDecimal extaxUnitpriceC; // 除税单价
    @TableField(value="intax_unitprice")
    private java.math.BigDecimal intaxUnitpriceC; // 含税单价
    @TableField(value="extax_price")
    private java.math.BigDecimal extaxPriceC; // 除税金额
    @TableField(value="intax_price")
    private java.math.BigDecimal intaxPriceC; // 含税金额
    @TableField(value="remarks")
    private java.lang.String remarksC; // 单位
    @TableField(value="withholding_other")
    private java.lang.String withholdingOther; // 扣款类型
    @TableField(value="cum_extax_price")
    private java.math.BigDecimal cumExtaxPrice; // 累计除税金额
    @TableField(value="cum_intax_price")
    private java.math.BigDecimal cumIntaxPrice; // 累计含税金额
    @TableField(value="cur_extax_price")
    private java.math.BigDecimal curExtaxPrice; // 本期除税金额
    @TableField(value="cur_intax_price")
    private java.math.BigDecimal curIntaxPrice; // 本期含税金额
    @TableField(value="is_deleted")
    private java.lang.String isDeleted;




    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 扣款名称
     */
    public java.lang.String getDeductionsName() {
        return deductionsName;
    }

    /**
     * 扣款名称
     */
    public void setDeductionsName(java.lang.String deductionsName) {
        this.deductionsName = deductionsName;
    }

    /**
     * 数量
     */
    public java.math.BigDecimal getNumber() {
        return number;
    }

    /**
     * 数量
     */
    public void setNumber(java.math.BigDecimal number) {
        this.number = number;
    }


    public BigDecimal getIntaxUnitpriceC() {
        return intaxUnitpriceC;
    }

    public void setIntaxUnitpriceC(BigDecimal intaxUnitpriceC) {
        this.intaxUnitpriceC = intaxUnitpriceC;
    }

    public BigDecimal getIntaxPriceC() {
        return intaxPriceC;
    }

    public void setIntaxPriceC(BigDecimal intaxPriceC) {
        this.intaxPriceC = intaxPriceC;
    }

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    public String getUnitsC() {
        return unitsC;
    }

    public void setUnitsC(String unitsC) {
        this.unitsC = unitsC;
    }

    public BigDecimal getExtaxUnitpriceC() {
        return extaxUnitpriceC;
    }

    public void setExtaxUnitpriceC(BigDecimal extaxUnitpriceC) {
        this.extaxUnitpriceC = extaxUnitpriceC;
    }

    public BigDecimal getExtaxPriceC() {
        return extaxPriceC;
    }

    public void setExtaxPriceC(BigDecimal extaxPriceC) {
        this.extaxPriceC = extaxPriceC;
    }

    public String getRemarksC() {
        return remarksC;
    }

    public void setRemarksC(String remarksC) {
        this.remarksC = remarksC;
    }

    public BigDecimal getCumExtaxPrice() {
        return cumExtaxPrice;
    }

    public void setCumExtaxPrice(BigDecimal cumExtaxPrice) {
        this.cumExtaxPrice = cumExtaxPrice;
    }

    public BigDecimal getCumIntaxPrice() {
        return cumIntaxPrice;
    }

    public void setCumIntaxPrice(BigDecimal cumIntaxPrice) {
        this.cumIntaxPrice = cumIntaxPrice;
    }

    public BigDecimal getCurExtaxPrice() {
        return curExtaxPrice;
    }

    public void setCurExtaxPrice(BigDecimal curExtaxPrice) {
        this.curExtaxPrice = curExtaxPrice;
    }

    public BigDecimal getCurIntaxPrice() {
        return curIntaxPrice;
    }

    public void setCurIntaxPrice(BigDecimal curIntaxPrice) {
        this.curIntaxPrice = curIntaxPrice;
    }

    public String getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(String isDeleted) {
        this.isDeleted = isDeleted;
    }
}
